@@ -1,4 +1,4 @@
-/*	$NetBSD: hdr.h,v 1.8 1999/07/28 23:23:39 hubertf Exp $	*/
+/*	$NetBSD: hdr.h,v 1.10 2003/08/07 09:36:50 agc Exp $	*/
 
 /*-
  * Copyright (c) 1991, 1993
@@ -17,11 +17,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -158,6 +154,6 @@ extern	int     turns, lmwarn, iwest, knfloc, detail,	/* various flags and
 	        abbnum, maxdie, numdie, holdng, dkill, foobar, bonus, clock1,
 	        clock2, saved, closng, panic, closed, scorng;
 
-extern	int     demo, newloc, limit;
+extern	int     demo, limit;
 
 #define DECR(a,b,c,d,e) decr(a+'+',b+'-',c+'#',d+'&',e+'%')
