@@ -1,4 +1,4 @@
-/*	$NetBSD: init.c,v 1.12 1999/07/28 23:23:39 hubertf Exp $	*/
+/*	$NetBSD: init.c,v 1.14 2003/08/07 09:36:50 agc Exp $	*/
 
 /*-
  * Copyright (c) 1993
@@ -17,11 +17,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -43,7 +39,7 @@
 #if 0
 static char sccsid[] = "@(#)init.c	8.1 (Berkeley) 6/2/93";
 #else
-__RCSID("$NetBSD: init.c,v 1.12 1999/07/28 23:23:39 hubertf Exp $");
+__RCSID("$NetBSD: init.c,v 1.14 2003/08/07 09:36:50 agc Exp $");
 #endif
 #endif /* not lint */
 
@@ -127,7 +123,7 @@ int     turns, lmwarn, iwest, knfloc, detail,	/* various flags and
         abbnum, maxdie, numdie, holdng, dkill, foobar, bonus, clock1,
         clock2, saved, closng, panic, closed, scorng;
 
-int     demo, newloc, limit;
+int     demo, limit;
 
 void
 init()			/* everything for 1st time run */
