@@ -1,4 +1,4 @@
-/*	$NetBSD: vocab.c,v 1.9 1998/09/14 09:29:09 hubertf Exp $	*/
+/*	$NetBSD: vocab.c,v 1.11 2003/08/07 09:36:51 agc Exp $	*/
 
 /*-
  * Copyright (c) 1991, 1993
@@ -17,11 +17,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -43,7 +39,7 @@
 #if 0
 static char sccsid[] = "@(#)vocab.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: vocab.c,v 1.9 1998/09/14 09:29:09 hubertf Exp $");
+__RCSID("$NetBSD: vocab.c,v 1.11 2003/08/07 09:36:51 agc Exp $");
 #endif
 #endif				/* not lint */
 
@@ -165,7 +161,7 @@ vocab(word, type, value)	/* look up or store a word      */
 			h->val = value;
 			h->atab = malloc(length(word));
 			if (h->atab == NULL)
-				errx(1, "Out of memory!");
+				err(1, NULL);
 			for (s = word, t = h->atab; *s;)
 				*t++ = *s++ ^ '=';
 			*t = 0 ^ '=';
