@@ -1,4 +1,4 @@
-/*	$NetBSD: tutor.h,v 1.5 1998/09/13 15:27:26 hubertf Exp $	*/
+/*	$NetBSD: tutor.h,v 1.8 2004/01/27 20:30:28 jsm Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -58,15 +54,15 @@ extern	const char	*const lastch[];
 extern	const char	*const list[];
 extern	int	 maxmoves;
 extern	const char	*const moves[];
-extern	const char	*opts;
+extern	const char	*const opts;
 extern	const char	*const prog[];
-extern	const char	*prompt;
+extern	const char	*const prompt;
 extern	const char	*const removepiece[];
 extern	const char	*const stragy[];
 extern	const struct situatn	test[];
 
 
-int	brdeq __P((const int *, const int *));
-void	clrest __P((void));
-void	leave __P((void)) __attribute__((__noreturn__));
-void	tutor __P((void)) __attribute__((__noreturn__));
+int	brdeq(const int *, const int *);
+void	clrest(void);
+void	leave(void) __attribute__((__noreturn__));
+void	tutor(void) __attribute__((__noreturn__));
