@@ -1,4 +1,4 @@
-/*	$NetBSD: crib.c,v 1.14 2001/02/05 00:28:30 christos Exp $	*/
+/*	$NetBSD: crib.c,v 1.19 2004/01/27 20:30:29 jsm Exp $	*/
 
 /*-
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -43,7 +39,7 @@ __COPYRIGHT("@(#) Copyright (c) 1980, 1993\n\
 #if 0
 static char sccsid[] = "@(#)crib.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: crib.c,v 1.14 2001/02/05 00:28:30 christos Exp $");
+__RCSID("$NetBSD: crib.c,v 1.19 2004/01/27 20:30:29 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -60,7 +56,7 @@ __RCSID("$NetBSD: crib.c,v 1.14 2001/02/05 00:28:30 christos Exp $");
 #include "cribcur.h"
 #include "pathnames.h"
 
-int	main __P((int, char *[]));
+int	main(int, char *[]);
 
 int
 main(argc, argv)
@@ -111,8 +107,8 @@ main(argc, argv)
 		}
 
 	initscr();
-	(void)signal(SIGINT, rint);
-	crmode();
+	(void)signal(SIGINT, receive_intr);
+	cbreak();
 	noecho();
 
 	Playwin = subwin(stdscr, PLAY_Y, PLAY_X, 0, 0);
@@ -132,7 +128,7 @@ main(argc, argv)
 			mvcur(0, COLS - 1, LINES - 1, 0);
 			fflush(stdout);
 			instructions();
-			crmode();
+			cbreak();
 			noecho();
 			clear();
 			refresh();
