@@ -1,4 +1,4 @@
-/*	$NetBSD: score.c,v 1.6 1998/08/30 09:19:37 veego Exp $	*/
+/*	$NetBSD: score.c,v 1.10 2003/08/07 09:37:10 agc Exp $	*/
 
 /*-
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)score.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: score.c,v 1.6 1998/08/30 09:19:37 veego Exp $");
+__RCSID("$NetBSD: score.c,v 1.10 2003/08/07 09:37:10 agc Exp $");
 #endif
 #endif /* not lint */
 
@@ -122,7 +118,7 @@ scorehand(hand, starter, n, crb, do_explain)
 	CARD h[(CINHAND + 1)];
 	char buf[32];
 
-	expl[0] = '\0';		/* initialize explanation */
+	explan[0] = '\0';	/* initialize explanation */
 	score = 0;
 	flag = TRUE;
 	k = hand[0].suit;
@@ -132,29 +128,29 @@ scorehand(hand, starter, n, crb, do_explain)
 			if (hand[i].suit == starter.suit) {
 				score++;
 				if (do_explain)
-					strcat(expl, "His Nobs");
+					strcat(explan, "His Nobs");
 			}
 		h[i] = hand[i];
 	}
 
 	if (flag && n >= CINHAND) {
-		if (do_explain && expl[0] != '\0')
-			strcat(expl, ", ");
+		if (do_explain && explan[0] != '\0')
+			strcat(explan, ", ");
 		if (starter.suit == k) {
 			score += 5;
 			if (do_explain)
-				strcat(expl, "Five-flush");
+				strcat(explan, "Five-flush");
 		} else
 			if (!crb) {
 				score += 4;
-				if (do_explain && expl[0] != '\0')
-					strcat(expl, ", Four-flush");
+				if (do_explain && explan[0] != '\0')
+					strcat(explan, ", Four-flush");
 				else
-					strcpy(expl, "Four-flush");
+					strcpy(explan, "Four-flush");
 			}
 	}
-	if (do_explain && expl[0] != '\0')
-		strcat(expl, ", ");
+	if (do_explain && explan[0] != '\0')
+		strcat(explan, ", ");
 	h[n] = starter;
 	sorthand(h, n + 1);	/* sort by rank */
 	i = 2 * fifteens(h, n + 1);
@@ -162,9 +158,9 @@ scorehand(hand, starter, n, crb, do_explain)
 	if (do_explain) {
 		if (i > 0) {
 			(void) sprintf(buf, "%d points in fifteens", i);
-			strcat(expl, buf);
+			strcat(explan, buf);
 		} else
-			strcat(expl, "No fifteens");
+			strcat(explan, "No fifteens");
 	}
 	i = pairuns(h, n + 1);
 	score += i;
@@ -172,9 +168,9 @@ scorehand(hand, starter, n, crb, do_explain)
 		if (i > 0) {
 			(void) sprintf(buf, ", %d points in pairs, %d in runs",
 			    pairpoints, runpoints);
-			strcat(expl, buf);
+			strcat(explan, buf);
 		} else
-			strcat(expl, ", No pairs/runs");
+			strcat(explan, ", No pairs/runs");
 	}
 	return (score);
 }
