@@ -1,4 +1,4 @@
-/*	$NetBSD: main.c,v 1.5 1998/02/03 05:40:45 perry Exp $	*/
+/*	$NetBSD: main.c,v 1.12 2004/01/27 20:30:29 jsm Exp $	*/
 
 /*
  * Copyright (c) 1994
@@ -15,11 +15,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -46,7 +42,7 @@ __COPYRIGHT("@(#) Copyright (c) 1994\n\
 #if 0
 static char sccsid[] = "@(#)main.c	8.4 (Berkeley) 5/4/95";
 #else
-__RCSID("$NetBSD: main.c,v 1.5 1998/02/03 05:40:45 perry Exp $");
+__RCSID("$NetBSD: main.c,v 1.12 2004/01/27 20:30:29 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -83,7 +79,7 @@ int	movelog[BSZ * BSZ];		/* log of all the moves */
 int	movenum;			/* current move number */
 const char	*plyr[2];			/* who's who */
 
-int	main __P((int, char *[]));
+int	main(int, char *[]);
 
 int
 main(argc, argv)
@@ -98,7 +94,7 @@ main(argc, argv)
 		"%3d        %-6s"
 	};
 
-	/* revoke setgid privileges */
+	/* Revoke setgid privileges */
 	setregid(getgid(), getgid());
 
 	color = curmove = 0;
