@@ -1,4 +1,4 @@
-/*	$NetBSD: pickmove.c,v 1.5 1997/10/10 13:36:06 lukem Exp $	*/
+/*	$NetBSD: pickmove.c,v 1.11 2004/01/27 20:26:20 jsm Exp $	*/
 
 /*
  * Copyright (c) 1994
@@ -15,11 +15,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -41,18 +37,14 @@
 #if 0
 static char sccsid[] = "@(#)pickmove.c	8.2 (Berkeley) 5/3/95";
 #else
-__RCSID("$NetBSD: pickmove.c,v 1.5 1997/10/10 13:36:06 lukem Exp $");
+__RCSID("$NetBSD: pickmove.c,v 1.11 2004/01/27 20:26:20 jsm Exp $");
 #endif
 #endif /* not lint */
 
 #include <stdlib.h>
 #include <string.h>
 #include <curses.h>
-#ifndef __linux__
-#include <machine/limits.h>
-#else
 #include <limits.h>
-#endif
 
 #include "gomoku.h"
 
