@@ -1,4 +1,4 @@
-/*	$NetBSD: extern.c,v 1.4 1997/10/11 01:16:27 lukem Exp $	*/
+/*	$NetBSD: extern.c,v 1.8 2003/08/07 09:37:20 agc Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)extern.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: extern.c,v 1.4 1997/10/11 01:16:27 lukem Exp $");
+__RCSID("$NetBSD: extern.c,v 1.8 2003/08/07 09:37:20 agc Exp $");
 #endif
 #endif /* not lint */
 
@@ -61,6 +57,7 @@ const char *const Noose_pict[] = {
 };
 
 int     Errors, Wordnum = 0;
+unsigned int Minlen = MINLEN;
 
 double  Average = 0.0;
 
@@ -74,6 +71,8 @@ const ERR_POS Err_pos[MAXERRS] = {
 	{5, 11, '\\'}
 };
 
+const char *Dict_name = _PATH_DICT;
+
 FILE   *Dict = NULL;
 
 off_t   Dict_size;
