@@ -1,4 +1,4 @@
-/*	$NetBSD: setup.c,v 1.5 1997/10/11 08:01:06 lukem Exp $	*/
+/*	$NetBSD: setup.c,v 1.10 2003/08/07 09:37:22 agc Exp $	*/
 
 /*-
  * Copyright (c) 1983, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)setup.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: setup.c,v 1.5 1997/10/11 08:01:06 lukem Exp $");
+__RCSID("$NetBSD: setup.c,v 1.10 2003/08/07 09:37:22 agc Exp $");
 #endif
 #endif				/* not lint */
 
@@ -57,7 +53,7 @@ setup()
 	static struct stat sbuf;
 
 	noecho();
-	crmode();
+	cbreak();
 
 	mvaddstr(PROMPTY, PROMPTX, "Guess:");
 	mvaddstr(GUESSY, GUESSX, "Guessed:");
@@ -72,9 +68,9 @@ setup()
 	}
 
 	srand(time(NULL) + getpid());
-	if ((Dict = fopen(_PATH_DICT, "r")) == NULL) {
+	if ((Dict = fopen(Dict_name, "r")) == NULL) {
 		endwin();
-		err(1, "fopen %s", _PATH_DICT);
+		err(1, "fopen %s", Dict_name);
 	}
 	fstat(fileno(Dict), &sbuf);
 	Dict_size = sbuf.st_size;
