@@ -1,4 +1,4 @@
-/*	$NetBSD: cards.c,v 1.11 1999/12/30 01:40:08 simonb Exp $	*/
+/*	$NetBSD: cards.c,v 1.14 2004/01/27 20:30:30 jsm Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)cards.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: cards.c,v 1.11 1999/12/30 01:40:08 simonb Exp $");
+__RCSID("$NetBSD: cards.c,v 1.14 2004/01/27 20:30:30 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -61,8 +57,8 @@ static const char	*cardfile	= "cards.pck";
 
 static FILE	*deckf;
 
-static void set_up __P((DECK *));
-static void printmes __P((void));
+static void set_up(DECK *);
+static void printmes(void);
 
 /*
  *	This routine initializes the decks from the data file,
@@ -101,7 +97,7 @@ set_up(dp)
 	int r1, r2;
 	int i;
 
-	dp->offsets = (u_int64_t *) calloc(sizeof (u_int64_t), dp->num_cards);
+	dp->offsets = (u_int64_t *) calloc(dp->num_cards, sizeof (u_int64_t));
 	if (dp->offsets == NULL)
 		err(1, NULL);
 	if (fread(dp->offsets, sizeof(u_int64_t), dp->num_cards, deckf) !=
