@@ -1,4 +1,4 @@
-/*	$NetBSD: monop.c,v 1.9 1999/09/12 09:02:22 jsm Exp $	*/
+/*	$NetBSD: monop.c,v 1.15 2004/01/27 20:30:30 jsm Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -43,7 +39,7 @@ __COPYRIGHT("@(#) Copyright (c) 1980, 1993\n\
 #if 0
 static char sccsid[] = "@(#)monop.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: monop.c,v 1.9 1999/09/12 09:02:22 jsm Exp $");
+__RCSID("$NetBSD: monop.c,v 1.15 2004/01/27 20:30:30 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -53,11 +49,12 @@ __RCSID("$NetBSD: monop.c,v 1.9 1999/09/12 09:02:22 jsm Exp $");
 #include <unistd.h>
 #include "monop.def"
 
-int main __P((int, char *[]));
-static void getplayers __P((void));
-static void init_players __P((void));
-static void init_monops __P((void));
-static void do_quit __P((int));
+int main(int, char *[]);
+static void getplayers(void);
+static void init_players(void);
+static void init_monops(void);
+static void do_quit(int);
+void *heapstart;
 
 /*
  *	This program implements a monopoly game
@@ -71,6 +68,7 @@ main(ac, av)
 	setregid(getgid(), getgid());
 
 	srand(getpid());
+	heapstart = sbrk(0);
 	if (ac > 1) {
 		if (!rest_f(av[1]))
 			restore();
@@ -120,7 +118,7 @@ blew_it:
 	}
 	cur_p = play = (PLAY *) calloc(num_play, sizeof (PLAY));
 	if (play == NULL)
-		errx(1, "out of memory");
+		err(1, NULL);
 	for (i = 0; i < num_play; i++) {
 over:
 		printf("Player %d's name: ", i + 1);
@@ -131,7 +129,7 @@ over:
 		*sp++ = '\0';
 		name_list[i] = play[i].name = (char *)calloc(1, sp - buf);
 		if (name_list[i] == NULL)
-			errx(1, "out of memory");
+			err(1, NULL);
 		strcpy(play[i].name, buf);
 		play[i].money = 1500;
 	}
@@ -187,7 +185,7 @@ again:
 }
 
 /*
- *	This routine initalizes the monopoly structures.
+ *	This routine initializes the monopoly structures.
  */
 static void
 init_monops() 
