@@ -1,4 +1,4 @@
-/*	$NetBSD: morg.c,v 1.8 1999/09/08 21:17:52 jsm Exp $	*/
+/*	$NetBSD: morg.c,v 1.10 2004/01/27 20:30:30 jsm Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)morg.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: morg.c,v 1.8 1999/09/08 21:17:52 jsm Exp $");
+__RCSID("$NetBSD: morg.c,v 1.10 2004/01/27 20:30:30 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -73,11 +69,11 @@ static short	square[MAX_PRP+2];
 static int	num_good,got_houses;
 
 
-static int set_mlist __P((void));
-static void m __P((int));
-static int set_umlist __P((void));
-static void unm __P((int));
-static void fix_ex __P((int));
+static int set_mlist(void);
+static void m(int);
+static int set_umlist(void);
+static void unm(int);
+static void fix_ex(int);
 
 /*
  *	This routine is the command level response the mortgage command.
