@@ -1,14 +1,16 @@
-/*	$NetBSD: gamesupport.c,v 1.4 1997/10/13 02:18:16 lukem Exp $	*/
+/*	$NetBSD: gamesupport.c,v 1.9 2005/02/15 12:58:21 jsm Exp $	*/
 
 /*
  * gamesupport.c - auxiliary routines for support of Phantasia
  */
 
 #include "include.h"
+#undef bool
+#include <curses.h>
 
 void
 changestats(ingameflag)
-	bool    ingameflag;
+	phbool  ingameflag;
 {
 	static char flag[2] =	/* for printing values of bools */
 	{'F', 'T'};
@@ -20,7 +22,7 @@ changestats(ingameflag)
 	long    loc;		/* location in player file */
 	time_t  now;		/* time now */
 	double  dtemp;		/* temporary variable */
-	bool   *bptr;		/* pointer to bool item to change */
+	phbool *bptr;		/* pointer to bool item to change */
 	double *dptr;		/* pointer to double item to change */
 	short  *sptr;		/* pointer to short item to change */
 
