@@ -1,10 +1,12 @@
-/*	$NetBSD: misc.c,v 1.10 2004/01/01 16:03:46 jsm Exp $	*/
+/*	$NetBSD: misc.c,v 1.14 2005/02/15 12:58:21 jsm Exp $	*/
 
 /*
  * misc.c  Phantasia miscellaneous support routines
  */
 
 #include "include.h"
+#undef bool
+#include <curses.h>
 
 
 void
@@ -63,7 +65,7 @@ movelevel()
 const char   *
 descrlocation(playerp, shortflag)
 	struct player *playerp;
-	bool    shortflag;
+	phbool  shortflag;
 {
 	double  circle;		/* corresponding circle for coordinates */
 	int     quadrant;	/* quandrant of grid */
@@ -445,7 +447,7 @@ allstatslist()
 const char   *
 descrtype(playerp, shortflag)
 	struct player *playerp;
-	bool    shortflag;
+	phbool  shortflag;
 {
 	int     type;		/* for caluculating result subscript */
 	static const char *const results[] =/* description table */
@@ -671,7 +673,7 @@ death(how)
 	if (ch == 'Y') {
 		cleanup(FALSE);
 		execl(_PATH_GAMEPROG, "phantasia", "-s",
-		    (Wizard ? "-S" : (char *) NULL), 0);
+		    (Wizard ? "-S" : (char *) NULL), (char *) NULL);
 		exit(0);
 		/* NOTREACHED */
 	}
