@@ -1,4 +1,4 @@
-/*	$NetBSD: pom.c,v 1.12 1999/09/14 20:00:07 jsm Exp $	*/
+/*	$NetBSD: pom.c,v 1.14 2004/01/27 20:30:30 jsm Exp $	*/
 
 /*
  * Copyright (c) 1989, 1993
@@ -14,11 +14,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -45,7 +41,7 @@ __COPYRIGHT("@(#) Copyright (c) 1989, 1993\n\
 #if 0
 static char sccsid[] = "@(#)pom.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: pom.c,v 1.12 1999/09/14 20:00:07 jsm Exp $");
+__RCSID("$NetBSD: pom.c,v 1.14 2004/01/27 20:30:30 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -88,12 +84,12 @@ __RCSID("$NetBSD: pom.c,v 1.12 1999/09/14 20:00:07 jsm Exp $");
 #define	Pzero	  36.340410	/* lunar mean long of perigee at EPOCH */
 #define	Nzero	  318.510107	/* lunar mean long of node at EPOCH */
 
-void	adj360 __P((double *));
-double	dtor __P((double));
-int	main __P((int, char *[]));
-double	potm __P((double));
-time_t	parsetime __P((char *));
-void	badformat __P((void)) __attribute__((__noreturn__));
+void	adj360(double *);
+double	dtor(double);
+int	main(int, char *[]);
+double	potm(double);
+time_t	parsetime(char *);
+void	badformat(void) __attribute__((__noreturn__));
 
 int
 main(argc, argv)
@@ -228,7 +224,7 @@ parsetime(p)
 	time_t tval;
 	unsigned char *t;
 	
-	for (t = p; *t; ++t) {
+	for (t = (unsigned char *)p; *t; ++t) {
 		if (isdigit(*t))
 			continue;
 		badformat();
