@@ -1,4 +1,4 @@
-/*	$NetBSD: extern.c,v 1.4 1997/10/12 14:09:56 lukem Exp $	*/
+/*	$NetBSD: extern.c,v 1.8 2003/08/07 09:37:36 agc Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)extern.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: extern.c,v 1.4 1997/10/12 14:09:56 lukem Exp $");
+__RCSID("$NetBSD: extern.c,v 1.8 2003/08/07 09:37:36 agc Exp $");
 #endif
 #endif /* not lint */
 
@@ -52,6 +48,7 @@ bool	Newscore;		/* There was a new score added */
 bool	Pattern_roll = FALSE;	/* Auto play for YHBJNLUK pattern */
 #endif
 bool	Real_time = FALSE;	/* Play in real time? */
+bool	Auto_bot = FALSE;	/* Automatic mover */
 bool	Running = FALSE;	/* Currently in the middle of a run */
 #ifdef	FANCY
 bool	Stand_still = FALSE;	/* Auto play for standing still pattern */
@@ -69,8 +66,10 @@ char	Run_ch;			/* Character for the direction we are running */
 int	Count = 0;		/* Command count */
 int	Level;			/* Current level */
 int	Num_robots;		/* Number of robots left */
+int	Num_scrap;		/* Number of scrap heaps */
 int	Num_scores;		/* Number of scores posted */
-int	Score;			/* Current score */
+int	Num_games;		/* Number of games to play */
+u_int32_t	Score;		/* Current score */
 int	Start_level = 1;	/* Level on which to start */
 int	Wait_bonus;		/* bonus for waiting */
 
@@ -78,5 +77,6 @@ COORD	Max;			/* Max area robots take up */
 COORD	Min;			/* Min area robots take up */
 COORD	My_pos;			/* Player's current position */
 COORD	Robots[MAXROBOTS];	/* Robots' current positions */
+COORD	Scrap[MAXROBOTS];	/* ScrapHeap' current position */
 
 jmp_buf	End_move;		/* Jump to on Real_time */
