@@ -1,4 +1,4 @@
-/*	$NetBSD: assorted.c,v 1.7 1999/02/10 00:45:45 hubertf Exp $	*/
+/*	$NetBSD: assorted.c,v 1.15 2003/08/07 09:37:41 agc Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,21 +34,18 @@
 #if 0
 static char sccsid[] = "@(#)assorted.c	8.2 (Berkeley) 4/28/95";
 #else
-__RCSID("$NetBSD: assorted.c,v 1.7 1999/02/10 00:45:45 hubertf Exp $");
+__RCSID("$NetBSD: assorted.c,v 1.15 2003/08/07 09:37:41 agc Exp $");
 #endif
 #endif /* not lint */
 
-#include "extern.h"
 #include <stdlib.h>
-#include <unistd.h>
 #include <err.h>
+#include "extern.h"
 
-static void strike __P((struct ship *, struct ship *));
+static void	strike (struct ship *, struct ship *);
 
 void
-table(rig, shot, hittable, on, from, roll)
-struct ship *on, *from;
-int rig, shot, hittable, roll;
+table(struct ship *from, struct ship *on, int rig, int shot, int hittable, int roll)
 {
 	int hhits = 0, chits = 0, ghits = 0, rhits = 0;
 	int Ghit = 0, Hhit = 0, Rhit = 0, Chit = 0;
@@ -244,9 +237,7 @@ int rig, shot, hittable, roll;
 }
 
 void
-Cleansnag(from, to, all, flag)
-struct ship *from, *to;
-char all, flag;
+Cleansnag(struct ship *from, struct ship *to, int all, int flag)
 {
 	if (flag & 1) {
 		Write(W_UNGRAP, from, to->file->index, all, 0, 0);
@@ -271,8 +262,7 @@ char all, flag;
 }
 
 static void
-strike(ship, from)
-struct ship *ship, *from;
+strike(struct ship *ship, struct ship *from)
 {
 	int points;
 
@@ -283,7 +273,7 @@ struct ship *ship, *from;
 	Write(W_POINTS, from, points, 0, 0, 0);
 	unboard(ship, ship, 0);		/* all offense */
 	unboard(ship, ship, 1);		/* all defense */
-	switch (die()) {
+	switch (dieroll()) {
 	case 3:
 	case 4:		/* ship may sink */
 		Write(W_SINK, ship, 1, 0, 0, 0);
