@@ -1,4 +1,4 @@
-/*	$NetBSD: dr_1.c,v 1.19 2003/08/07 09:37:41 agc Exp $	*/
+/*	$NetBSD: dr_1.c,v 1.21 2004/11/05 21:30:32 dsl Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -34,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)dr_1.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: dr_1.c,v 1.19 2003/08/07 09:37:41 agc Exp $");
+__RCSID("$NetBSD: dr_1.c,v 1.21 2004/11/05 21:30:32 dsl Exp $");
 #endif
 #endif /* not lint */
 
@@ -425,14 +425,11 @@ next(void)
 			if (tp == 0)
 				p = "Driver";
 			else {
-				if (islower(*tp))
-					*tp = toupper(*tp);
+				*tp = toupper((unsigned char)*tp);
 				p = tp;
 			}
-			strncpy(bestship->file->captain, p,
+			strlcpy(bestship->file->captain, p,
 				sizeof bestship->file->captain);
-			bestship->file->captain
-				[sizeof bestship->file->captain - 1] = 0;
 			logger(bestship);
 		}
 		return -1;
