@@ -1,4 +1,4 @@
-/*	$NetBSD: dr_5.c,v 1.6 1999/02/10 00:45:45 hubertf Exp $	*/
+/*	$NetBSD: dr_5.c,v 1.12 2003/08/07 09:37:42 agc Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,17 +34,15 @@
 #if 0
 static char sccsid[] = "@(#)dr_5.c	8.2 (Berkeley) 4/28/95";
 #else
-__RCSID("$NetBSD: dr_5.c,v 1.6 1999/02/10 00:45:45 hubertf Exp $");
+__RCSID("$NetBSD: dr_5.c,v 1.12 2003/08/07 09:37:42 agc Exp $");
 #endif
 #endif /* not lint */
 
+#include <sys/types.h>
 #include "extern.h"
 
 void
-subtract(from, totalfrom, crewfrom, fromcap, pcfrom)
-struct ship *from, *fromcap;
-int pcfrom;
-int  totalfrom, crewfrom[3];
+subtract(struct ship *from, struct ship *fromcap, int totalfrom, int *crewfrom, int pcfrom)
 {
 	int n;
 
@@ -71,10 +65,7 @@ int  totalfrom, crewfrom[3];
 }
 
 int
-mensent(from, to, crew, captured, pc, isdefense)
-struct ship *from, *to, **captured;
-int crew[3], *pc;
-char isdefense;
+mensent(struct ship *from, struct ship *to, int *crew, struct ship **captured, int *pc, int isdefense)
 {					/* returns # of crew squares sent */
 	int men = 0;
 	int n;
