@@ -1,4 +1,4 @@
-/*	$NetBSD: driver.h,v 1.6 1999/09/08 21:17:58 jsm Exp $	*/
+/*	$NetBSD: driver.h,v 1.8 2003/08/07 09:37:42 agc Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -35,6 +31,4 @@
  *	@(#)driver.h	8.2 (Berkeley) 5/3/95
  */
 
-#include "extern.h"
-
 extern const int dtab[];
