@@ -1,4 +1,4 @@
-/*	$NetBSD: extern.h,v 1.12 1999/09/30 18:01:33 jsm Exp $ */
+/*	$NetBSD: extern.h,v 1.27 2004/02/08 00:32:48 jsm Exp $ */
 
 /*
  * Copyright (c) 1983, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -35,34 +31,27 @@
  *	@(#)externs.h	8.1 (Berkeley) 5/31/93
  */
 
-#include <stdio.h>
-#include <signal.h>
-#include <string.h>
-#include <ctype.h>
-#include <setjmp.h>
 #include <sys/types.h>
+
 #include "machdep.h"
 
 	/* program mode */
 extern int mode;
-extern jmp_buf restart;
 #define MODE_PLAYER	1
 #define MODE_DRIVER	2
 #define MODE_LOGGER	3
 
 	/* command line flags */
-extern char debug;			/* -D */
-extern char randomize;			/* -x, give first available ship */
-extern char longfmt;			/* -l, print score in long format */
-extern char nobells;			/* -b, don't ring bell before Signal */
+extern int randomize;			/* -x, give first available ship */
+extern int longfmt;			/* -l, print score in long format */
+extern int nobells;			/* -b, don't ring bell before Signal */
 
 	/* other initial modes */
 extern gid_t gid;
 extern gid_t egid;
 
-#define die()		((rand() >> 3) % 6 + 1)
+#define dieroll()		((random()) % 6 + 1)
 #define sqr(a)		((a) * (a))
-#define abs(a)		((a) > 0 ? (a) : -(a))
 #define min(a,b)	((a) < (b) ? (a) : (b))
 
 #define grappled(a)	((a)->file->ngrap)
@@ -298,146 +287,127 @@ extern int turn;
 extern int game;
 extern int alive;
 extern int people;
-extern char hasdriver;
+extern int hasdriver;
 
 /* assorted.c */
-void table __P((int, int, int, struct ship *, struct ship *, int));
-void Cleansnag __P((struct ship *, struct ship *, int, int));
+void table (struct ship *, struct ship *, int, int, int, int);
+void Cleansnag (struct ship *, struct ship *, int, int);
 
 /* dr_1.c */
-void unfoul __P((void));
-void boardcomp __P((void));
-int fightitout __P((struct ship *, struct ship *, int));
-void resolve __P((void));
-void compcombat __P((void));
-int next __P((void));
+void unfoul (void);
+void boardcomp (void);
+void resolve (void);
+void compcombat (void);
+int next (void);
 
 /* dr_2.c */
-void thinkofgrapples __P((void));
-void checkup __P((void));
-void prizecheck __P((void));
-int str_end __P((const char *));
-void closeon __P((struct ship *, struct ship *, char[], int, int, int));
-int score __P((char[], struct ship *, struct ship *, int));
-void move_ship __P((const char *, struct ship *, unsigned char *, short *, short *, char *));
-void try __P((char[], char [], int, int, int, int, int, struct ship *,
-    struct ship *, int *, int));
-void rmend __P((char *));
+void thinkofgrapples (void);
+void checkup (void);
+void prizecheck (void);
+void closeon (struct ship *, struct ship *, char *, int, int, int);
 
 /* dr_3.c */
-void moveall __P((void));
-int stillmoving __P((int));
-int is_isolated __P((struct ship *));
-int push __P((struct ship *, struct ship *));
-void step __P((int, struct ship *, char *));
-void sendbp __P((struct ship *, struct ship *, int, int));
-int is_toughmelee __P((struct ship *, struct ship *, int, int));
-void reload __P((void));
-void checksails __P((void));
+void moveall (void);
+void sendbp (struct ship *, struct ship *, int, int);
+int is_toughmelee (struct ship *, struct ship *, int, int);
+void reload (void);
+void checksails (void);
 
 /* dr_4.c */
-void ungrap __P((struct ship *, struct ship *));
-void grap __P((struct ship *, struct ship *));
+void ungrap (struct ship *, struct ship *);
+void grap (struct ship *, struct ship *);
 
 /* dr_5.c */
-void subtract __P((struct ship *, int, int [3], struct ship *, int));
-int mensent __P((struct ship *, struct ship *, int[3], struct ship **, int *,
-    int));
+void subtract (struct ship *, struct ship *, int, int [3], int);
+int mensent (struct ship *, struct ship *, int[3], struct ship **, int *,
+    int);
 
 /* dr_main.c */
-int dr_main __P((void));
+int dr_main (void);
 
 /* game.c */
-int maxturns __P((struct ship *, char *));
-int maxmove __P((struct ship *, int, int));
+int maxturns (struct ship *, char *);
+int maxmove (struct ship *, int, int);
 
 /* lo_main.c */
-int lo_main __P((void));
+int lo_main (void);
 
 /* misc.c */
-int range __P((struct ship *, struct ship *));
-struct ship *closestenemy __P((struct ship *, int, int));
-int angle __P((int, int));
-int gunsbear __P((struct ship *, struct ship *));
-int portside __P((struct ship *, struct ship *, int));
-int colours __P((struct ship *));
-void logger __P((struct ship *));
+int range (struct ship *, struct ship *);
+struct ship *closestenemy (struct ship *, int, int);
+int gunsbear (struct ship *, struct ship *);
+int portside (struct ship *, struct ship *, int);
+int colours (struct ship *);
+void logger (struct ship *);
 
 /* parties.c */
-int meleeing __P((struct ship *, struct ship *));
-int boarding __P((struct ship *, int));
-void unboard __P((struct ship *, struct ship *, int));
+int meleeing (struct ship *, struct ship *);
+int boarding (struct ship *, int);
+void unboard (struct ship *, struct ship *, int);
 
 /* pl_1.c */
-void leave __P((int)) __attribute__((__noreturn__));
-void choke __P((int)) __attribute__((__noreturn__));
-void child __P((int));
+void leave (int) __attribute__((__noreturn__));
+void choke (int) __attribute__((__noreturn__));
+void child (int);
 
 /* pl_2.c */
-void play __P((void)) __attribute__((__noreturn__));
+void play (void) __attribute__((__noreturn__));
 
 /* pl_3.c */
-void acceptcombat __P((void));
-void grapungrap __P((void));
-void unfoulplayer __P((void));
+void acceptcombat (void);
+void grapungrap (void);
+void unfoulplayer (void);
 
 /* pl_4.c */
-void changesail __P((void));
-void acceptsignal __P((void));
-void lookout __P((void));
-const char *saywhat __P((struct ship *, int));
-void eyeball __P((struct ship *));
+void changesail (void);
+void acceptsignal (void);
+void lookout (void);
+const char *saywhat (struct ship *, int);
+void eyeball (struct ship *);
 
 /* pl_5.c */
-void acceptmove __P((void));
-void acceptboard __P((void));
-void parties __P((int[3], struct ship *, int, int));
+void acceptmove (void);
+void acceptboard (void);
 
 /* pl_6.c */
-void repair __P((void));
-int turned __P((void));
-void loadplayer __P((void));
+void repair (void);
+void loadplayer (void);
 
 /* pl_7.c */
-void initscreen __P((void));
-void cleanupscreen __P((void));
-void newturn __P((int));
-void Signal __P((const char *, struct ship *, ...))
+void initscreen (void);
+void cleanupscreen (void);
+void newturn (int);
+void Signal (const char *, struct ship *, ...)
 	 __attribute__((__format__(__printf__,1,3)));
-void Msg __P((const char *, ...))
+void Msg (const char *, ...)
 	 __attribute__((__format__(__printf__,1,2)));
-void Scroll __P((void));
-void prompt __P((const char *, struct ship *));
-void endprompt __P((int));
-int sgetch __P((const char *, struct ship *, int));
-void sgetstr __P((const char *, char *, int));
-void draw_screen __P((void));
-void draw_view __P((void));
-void draw_turn __P((void));
-void draw_stat __P((void));
-void draw_slot __P((void));
-void draw_board __P((void));
-void centerview __P((void));
-void upview __P((void));
-void downview __P((void));
-void leftview __P((void));
-void rightview __P((void));
-void adjustview __P((void));
+void prompt (const char *, struct ship *);
+int sgetch (const char *, struct ship *, int);
+void sgetstr (const char *, char *, int);
+void draw_screen (void);
+void draw_view (void);
+void draw_turn (void);
+void draw_stat (void);
+void draw_slot (void);
+void draw_board (void);
+void centerview (void);
+void upview (void);
+void downview (void);
+void leftview (void);
+void rightview (void);
 
 /* pl_main.c */
-int pl_main __P((void));
-void initialize __P((void));
+int pl_main (void);
 
 /* sync.c */
-void fmtship __P((char *, size_t, const char *, struct ship *));
-void makesignal __P((struct ship *, const char *, struct ship *, ...))
+void fmtship (char *, size_t, const char *, struct ship *);
+void makesignal (struct ship *, const char *, struct ship *, ...)
 	 __attribute__((__format__(__printf__,2,4)));
-void makemsg __P((struct ship *, const char *, ...))
+void makemsg (struct ship *, const char *, ...)
 	 __attribute__((__format__(__printf__,2,3)));
-int sync_exists __P((int));
-int sync_open __P((void));
-void sync_close __P((int));
-void Write __P((int, struct ship *, long, long, long, long));
-void Writestr __P((int, struct ship *, const char *));
-int Sync __P((void));
-int sync_update __P((int, struct ship *, const char *, long, long, long, long));
+int sync_exists (int);
+int sync_open (void);
+void sync_close (int);
+void Write (int, struct ship *, long, long, long, long);
+void Writestr (int, struct ship *, const char *);
+int Sync (void);
