@@ -1,4 +1,4 @@
-/*	$NetBSD: lo_main.c,v 1.5 1997/10/13 19:44:24 christos Exp $	*/
+/*	$NetBSD: lo_main.c,v 1.12 2003/08/07 09:37:43 agc Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)lo_main.c	8.2 (Berkeley) 4/28/95";
 #else
-__RCSID("$NetBSD: lo_main.c,v 1.5 1997/10/13 19:44:24 christos Exp $");
+__RCSID("$NetBSD: lo_main.c,v 1.12 2003/08/07 09:37:43 agc Exp $");
 #endif
 #endif /* not lint */
 
@@ -47,7 +43,9 @@ __RCSID("$NetBSD: lo_main.c,v 1.5 1997/10/13 19:44:24 christos Exp $");
  *
  * -l force a long listing (print out real usernames)
  */
-#include <sys/types.h>
+
+#include <stdio.h>
+#include <stdlib.h>
 #include <pwd.h>
 #include "extern.h"
 #include "pathnames.h"
@@ -59,7 +57,7 @@ const char *const title[] = {
 };
 
 int
-lo_main()
+lo_main(void)
 {
 	FILE *fp;
 	char sbuf[32];
@@ -85,10 +83,9 @@ lo_main()
 	while (fread((char *)&log, sizeof log, 1, fp) == 1 &&
 	       log.l_name[0] != '\0') {
 		if (longfmt && (pass = getpwuid(log.l_uid)) != NULL)
-			(void) sprintf(sbuf, "%10.10s (%s)",
-				log.l_name, pass->pw_name);
+			sprintf(sbuf, "%10.10s (%s)", log.l_name, pass->pw_name);
 		else
-			(void) sprintf(sbuf, "%20.20s", log.l_name);
+			sprintf(sbuf, "%20.20s", log.l_name);
 		ship = &scene[log.l_gamenum].ship[log.l_shipnum];
 		printf("%-10s %21s of the %15s %3d points, %5.2f equiv\n",
 			title[n++], sbuf, ship->shipname, log.l_netpoints,
