@@ -1,4 +1,4 @@
-/*	$NetBSD: pl_1.c,v 1.6 1999/02/10 00:45:46 hubertf Exp $	*/
+/*	$NetBSD: pl_1.c,v 1.18 2004/01/27 20:23:36 jsm Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,14 +34,18 @@
 #if 0
 static char sccsid[] = "@(#)pl_1.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: pl_1.c,v 1.6 1999/02/10 00:45:46 hubertf Exp $");
+__RCSID("$NetBSD: pl_1.c,v 1.18 2004/01/27 20:23:36 jsm Exp $");
 #endif
 #endif /* not lint */
 
-#include "player.h"
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <signal.h>
+#include <stdio.h>
+#include <stdlib.h>
 #include <unistd.h>
+#include "extern.h"
+#include "player.h"
 
 /*
  * If we get here before a ship is chosen, then ms == 0 and
@@ -56,14 +56,13 @@ __RCSID("$NetBSD: pl_1.c,v 1.6 1999/02/10 00:45:46 hubertf Exp $");
  * because of a Sync() failure.
  */
 void
-leave(conditions)
-int conditions;
+leave(int conditions)
 {
-	(void) signal(SIGHUP, SIG_IGN);
-	(void) signal(SIGINT, SIG_IGN);
-	(void) signal(SIGQUIT, SIG_IGN);
-	(void) signal(SIGALRM, SIG_IGN);
-	(void) signal(SIGCHLD, SIG_IGN);
+	signal(SIGHUP, SIG_IGN);
+	signal(SIGINT, SIG_IGN);
+	signal(SIGQUIT, SIG_IGN);
+	signal(SIGALRM, SIG_IGN);
+	signal(SIGCHLD, SIG_IGN);
 
 	if (done_curses) {
 		Msg("It looks like you've had it!");
@@ -110,7 +109,7 @@ int conditions;
 			makemsg(ms, "Captain %s relinquishing.",
 				mf->captain);
 			Write(W_END, ms, 0, 0, 0, 0);
-			(void) Sync();
+			Sync();
 		}
 	}
 	sync_close(!hasdriver);
@@ -121,25 +120,23 @@ int conditions;
 
 /*ARGSUSED*/
 void
-choke(n)
-	int n __attribute__((__unused__));
+choke(int n __attribute__((__unused__)))
 {
 	leave(LEAVE_QUIT);
 }
 
 /*ARGSUSED*/
 void
-child(n)
-	int n __attribute__((__unused__));
+child(int n __attribute__((__unused__)))
 {
-	union wait status;
+	int status;
 	int pid;
 
-	(void) signal(SIGCHLD, SIG_IGN);
+	signal(SIGCHLD, SIG_IGN);
 	do {
-		pid = wait3((int *)&status, WNOHANG, (struct rusage *)0);
+		pid = wait3(&status, WNOHANG, (struct rusage *)0);
 		if (pid < 0 || (pid > 0 && !WIFSTOPPED(status)))
 			hasdriver = 0;
 	} while (pid > 0);
-	(void) signal(SIGCHLD, child);
+	signal(SIGCHLD, child);
 }
