@@ -1,4 +1,4 @@
-/*	$NetBSD: tetris.c,v 1.12 1999/09/12 09:02:24 jsm Exp $	*/
+/*	$NetBSD: tetris.c,v 1.17 2004/01/27 20:30:30 jsm Exp $	*/
 
 /*-
  * Copyright (c) 1992, 1993
@@ -15,11 +15,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -50,6 +46,7 @@ __COPYRIGHT("@(#) Copyright (c) 1992, 1993\n\
 
 #include <sys/time.h>
 
+#include <err.h>
 #include <fcntl.h>
 #include <signal.h>
 #include <stdio.h>
@@ -77,11 +74,11 @@ gid_t	gid, egid;
 char	key_msg[100];
 int	showpreview;
 
-static	void	elide __P((void));
-static	void	setup_board __P((void));
-	int	main __P((int, char **));
-	void	onintr __P((int)) __attribute__((__noreturn__));
-	void	usage __P((void)) __attribute__((__noreturn__));
+static	void	elide(void);
+static	void	setup_board(void);
+	int	main(int, char **);
+	void	onintr(int) __attribute__((__noreturn__));
+	void	usage(void) __attribute__((__noreturn__));
 
 /*
  * Set up the initial board.  The bottom display row is completely set,
@@ -91,8 +88,8 @@ static	void	setup_board __P((void));
 static void
 setup_board()
 {
-	register int i;
-	register cell *p;
+	int i;
+	cell *p;
 
 	p = board;
 	for (i = B_SIZE; i; i--)
@@ -105,8 +102,8 @@ setup_board()
 static void
 elide()
 {
-	register int i, j, base;
-	register cell *p;
+	int i, j, base;
+	cell *p;
 
 	for (i = A_FIRST; i < A_LAST; i++) {
 		base = i * B_COLS + 1;
@@ -132,9 +129,9 @@ main(argc, argv)
 	int argc;
 	char *argv[];
 {
-	register int pos, c;
-	register const char *keys;
-	register int level = 2;
+	int pos, c;
+	const char *keys;
+	int level = 2;
 	char key_write[6][10];
 	int ch, i, j;
 	int fd;
@@ -159,10 +156,8 @@ main(argc, argv)
 		case 'l':
 			level = atoi(optarg);
 			if (level < MINLEVEL || level > MAXLEVEL) {
-				(void)fprintf(stderr,
-				    "tetris: level must be from %d to %d\n",
-				    MINLEVEL, MAXLEVEL);
-				exit(1);
+				errx(1, "level must be from %d to %d",
+				     MINLEVEL, MAXLEVEL);
 			}
 			break;
 		case 'p':
@@ -187,10 +182,7 @@ main(argc, argv)
 	for (i = 0; i <= 5; i++) {
 		for (j = i+1; j <= 5; j++) {
 			if (keys[i] == keys[j]) {
-				(void)fprintf(stderr,
-				    "%s: duplicate command keys specified.\n",
-				    argv[0]);
-				exit (1);
+				errx(1, "duplicate command keys specified.");
 			}
 		}
 		if (keys[i] == ' ')
@@ -340,6 +332,6 @@ onintr(signo)
 void
 usage()
 {
-	(void)fprintf(stderr, "usage: tetris [-ps] [-k keys] [-l level]\n");
+	(void)fprintf(stderr, "usage: tetris-bsd [-ps] [-k keys] [-l level]\n");
 	exit(1);
 }
