@@ -1,4 +1,4 @@
-/*	$NetBSD: externs.c,v 1.4 1997/10/12 21:24:48 christos Exp $	*/
+/*	$NetBSD: externs.c,v 1.8 2003/08/07 09:37:51 agc Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)externs.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: externs.c,v 1.4 1997/10/12 21:24:48 christos Exp $");
+__RCSID("$NetBSD: externs.c,v 1.8 2003/08/07 09:37:51 agc Exp $");
 #endif
 #endif /* not lint */
 
@@ -103,3 +99,19 @@ const char	*const Systemname[NINHAB] =
 	"Epsilon Eridani IV",
 	"Exo III"
 };
+
+struct quad	Quad[NQUADS][NQUADS];
+
+/* current sector map */
+char	Sect[NSECTS][NSECTS];
+
+struct event	Event[MAXEVENTS];	/* dynamic event list; one entry per pending event */
+
+struct Ship_struct Ship;
+struct Game_struct Game;
+struct Move_struct Move;
+struct Param_struct Param;
+struct Now_struct Now;
+struct Etc_struct Etc;
+
+int Trace;
