@@ -1,4 +1,4 @@
-/*	$NetBSD: torped.c,v 1.4 1997/10/12 21:25:22 christos Exp $	*/
+/*	$NetBSD: torped.c,v 1.8 2004/01/27 20:30:31 jsm Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,11 +34,12 @@
 #if 0
 static char sccsid[] = "@(#)torped.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: torped.c,v 1.4 1997/10/12 21:25:22 christos Exp $");
+__RCSID("$NetBSD: torped.c,v 1.8 2004/01/27 20:30:31 jsm Exp $");
 #endif
 #endif /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <math.h>
 #include "trek.h"
 #include "getpar.h"
@@ -66,7 +63,7 @@ __RCSID("$NetBSD: torped.c,v 1.4 1997/10/12 21:25:22 christos Exp $");
 **	the misfire damages your torpedo tubes.
 */
 
-static int randcourse __P((int));
+static int randcourse(int);
 
 /*ARGSUSED*/
 void
